@@ -6,7 +6,7 @@ from collections import namedtuple
 from dataclasses import dataclass
 
 from stream2py.stream_buffer import StreamBuffer
-from stream2py.sources.audio import PyAudioSourceReader
+from audiostream2py import PyAudioSourceReader
 from taped.util import (
     DFLT_SR,
     DFLT_SAMPLE_WIDTH,
